@@ -1,12 +1,15 @@
+from .message import MessageCallback, MessageContext
 from .query import QueryCallback, QueryContext
 from .text import TextCallback, TextContext
 from .update import UpdateCallback, UpdateContext
 
 __all__ = [
     "UpdateContext",
+    "MessageContext",
     "QueryContext",
     "TextContext",
     "UpdateCallback",
+    "MessageCallback",
     "QueryCallback",
     "TextCallback",
 ]
