@@ -1,4 +1,4 @@
-from .command import CommandHandler
+from .command import CommandHandler, CommandsHandler
 from .composite import CompositeHandler
 from .inline_menu import InlineMenuHandler
 from .message import MessageHandler
@@ -18,4 +18,5 @@ __all__ = [
     "StartHandler",
     "StartGroupHandler",
     "InlineMenuHandler",
+    "CommandsHandler",
 ]
