@@ -4,7 +4,7 @@ from telegram.constants import ParseMode
 from telegram.ext import Application, Defaults
 from telegram.warnings import PTBUserWarning
 
-from .types import PTBHandler
+from .ptb_types import PTBHandler
 
 warnings.filterwarnings(
     action="ignore",
