@@ -1,11 +1,11 @@
 from collections.abc import Awaitable, Callable
-from typing import Any, TypeVar
+from typing import TypeVar
 
 import telegram
 
 from botty_core.types import Bot, Chat, Message, Update, User
 
-from .ptb_types import PTBContext
+from .ptb_types import PTBContext, ReturnType
 
 
 class Context:
@@ -32,4 +32,4 @@ class Context:
 
 
 ContextT = TypeVar("ContextT", bound=Context)
-Callback = Callable[[ContextT], Awaitable[Any]]  # TODO
+Callback = Callable[[ContextT], Awaitable[ReturnType]]
